@@ -8,6 +8,7 @@
 #![deny(rustdoc::all)]
 #![allow(rustdoc::missing_doc_code_examples)]
 #![deny(clippy::unwrap_used)]
+#![allow(deprecated)]
 
 use anchor_lang::prelude::*;
 use vipers::prelude::*;
@@ -30,6 +31,7 @@ pub mod gauge {
 
     /// Creates a [Gaugemeister].
     #[access_control(ctx.accounts.validate())]
+    #[deprecated(note = "Use `create_gaugemeister_v2` instead.")]
     pub fn create_gaugemeister(
         ctx: Context<CreateGaugemeister>,
         _bump: u8,
@@ -40,24 +42,64 @@ pub mod gauge {
         create_gaugemeister::handler(ctx, foreman, epoch_duration_seconds, first_epoch_starts_at)
     }
 
+    /// Creates a [Gaugemeister].
+    ///
+    /// The V2 variant removes the need to supply a bump seed.
+    #[access_control(ctx.accounts.validate())]
+    pub fn create_gaugemeister_v2(
+        ctx: Context<CreateGaugemeister>,
+        foreman: Pubkey,
+        epoch_duration_seconds: u32,
+        first_epoch_starts_at: u64,
+    ) -> Result<()> {
+        create_gaugemeister::handler(ctx, foreman, epoch_duration_seconds, first_epoch_starts_at)
+    }
+
     /// Creates a [Gauge]. Permissionless.
+    #[deprecated(note = "Use `create_gauge_v2` instead.")]
     #[access_control(ctx.accounts.validate())]
     pub fn create_gauge(ctx: Context<CreateGauge>, _bump: u8) -> Result<()> {
         create_gauge::handler(ctx)
     }
 
+    /// Creates a [Gauge]. Permissionless.
+    ///
+    /// The V2 variant removes the need to supply a bump seed.
+    #[access_control(ctx.accounts.validate())]
+    pub fn create_gauge_v2(ctx: Context<CreateGauge>) -> Result<()> {
+        create_gauge::handler(ctx)
+    }
+
     /// Creates a [GaugeVoter]. Permissionless.
+    #[deprecated(note = "Use `create_gauge_voter_v2` instead.")]
     #[access_control(ctx.accounts.validate())]
     pub fn create_gauge_voter(ctx: Context<CreateGaugeVoter>, _bump: u8) -> Result<()> {
         create_gauge_voter::handler(ctx)
     }
 
+    /// Creates a [GaugeVoter]. Permissionless.
+    ///
+    /// The V2 variant removes the need to supply a bump seed.
+    #[access_control(ctx.accounts.validate())]
+    pub fn create_gauge_voter_v2(ctx: Context<CreateGaugeVoter>) -> Result<()> {
+        create_gauge_voter::handler(ctx)
+    }
+
     /// Creates a [GaugeVote]. Permissionless.
+    #[deprecated(note = "Use `create_gauge_vote_v2` instead.")]
     #[access_control(ctx.accounts.validate())]
     pub fn create_gauge_vote(ctx: Context<CreateGaugeVote>, _bump: u8) -> Result<()> {
         create_gauge_vote::handler(ctx)
     }
 
+    /// Creates a [GaugeVote]. Permissionless.
+    ///
+    /// The V2 variant removes the need to supply a bump seed.
+    #[access_control(ctx.accounts.validate())]
+    pub fn create_gauge_vote_v2(ctx: Context<CreateGaugeVote>) -> Result<()> {
+        create_gauge_vote::handler(ctx)
+    }
+
     /// Creates an [EpochGauge]. Permissionless.
     #[access_control(ctx.accounts.validate())]
     pub fn create_epoch_gauge(
@@ -69,6 +111,7 @@ pub mod gauge {
     }
 
     /// Creates an [EpochGaugeVoter]. Permissionless.
+    #[deprecated(note = "Use `prepare_epoch_gauge_voter_v2` instead.")]
     #[access_control(ctx.accounts.validate())]
     pub fn prepare_epoch_gauge_voter(
         ctx: Context<PrepareEpochGaugeVoter>,
@@ -76,6 +119,13 @@ pub mod gauge {
     ) -> Result<()> {
         prepare_epoch_gauge_voter::handler(ctx)
     }
+    /// Creates an [EpochGaugeVoter]. Permissionless.
+    ///
+    /// The V2 variant removes the need to supply a bump seed.
+    #[access_control(ctx.accounts.validate())]
+    pub fn prepare_epoch_gauge_voter_v2(ctx: Context<PrepareEpochGaugeVoter>) -> Result<()> {
+        prepare_epoch_gauge_voter::handler(ctx)
+    }
 
     /// Resets an [EpochGaugeVoter]; that is, syncs the [EpochGaugeVoter]
     /// with the latest power amount only if the votes have yet to be
@@ -93,11 +143,21 @@ pub mod gauge {
 
     /// Commits the vote of a [Gauge].
     /// Anyone can call this on any voter's gauge votes.
+    #[deprecated(note = "Use `gauge_commit_vote_v2` instead.")]
     #[access_control(ctx.accounts.validate())]
     pub fn gauge_commit_vote(ctx: Context<GaugeCommitVote>, _vote_bump: u8) -> Result<()> {
         gauge_commit_vote::handler(ctx)
     }
 
+    /// Commits the vote of a [Gauge].
+    /// Anyone can call this on any voter's gauge votes.
+    ///
+    /// The V2 variant removes the need to supply a bump seed.
+    #[access_control(ctx.accounts.validate())]
+    pub fn gauge_commit_vote_v2(ctx: Context<GaugeCommitVote>) -> Result<()> {
+        gauge_commit_vote::handler(ctx)
+    }
+
     /// Reverts a vote commitment of a [Gauge].
     /// Only the voter can call this.
     #[access_control(ctx.accounts.validate())]
@@ -139,6 +199,17 @@ pub mod gauge {
     ) -> Result<()> {
         set_gaugemeister_params::handler(ctx, new_epoch_duration_seconds, new_foreman)
     }
+
+    /// Closes an [EpochGaugeVote], sending lamports to a user-specified address.
+    ///
+    /// Only the [locked_voter::Escrow::vote_delegate] may call this.
+    #[access_control(ctx.accounts.validate())]
+    pub fn close_epoch_gauge_vote(
+        ctx: Context<CloseEpochGaugeVote>,
+        voting_epoch: u32,
+    ) -> Result<()> {
+        instructions::close_epoch_gauge_vote::handler(ctx, voting_epoch)
+    }
 }
 
 /// Errors.
@@ -168,4 +239,8 @@ pub enum ErrorCode {
     EpochClosed,
     #[msg("You must have zero allocated power in order to reset the epoch gauge.")]
     AllocatedPowerMustBeZero,
+    #[msg("The epoch in which you are closing an account for has not yet elapsed.")]
+    CloseEpochNotElapsed,
+    #[msg("You must be the vote delegate of the escrow to perform this action.")]
+    UnauthorizedNotDelegate,
 }
