@@ -1,5 +1,7 @@
 //! Struct definitions for accounts that hold state.
 
+use anchor_lang::solana_program::pubkey::PUBKEY_BYTES;
+
 use crate::*;
 
 /// Manages the rewards shares of all [Gauge]s of a [quarry_mine::rewarder].
@@ -40,6 +42,9 @@ pub struct Gaugemeister {
 }
 
 impl Gaugemeister {
+    /// Length of a [Gaugemeister] in bytes.
+    pub const LEN: usize = PUBKEY_BYTES + 1 + PUBKEY_BYTES * 4 + 4 + 4 + 8 + PUBKEY_BYTES * 2;
+
     /// Fetches the current voting epoch. This is always the epoch after [Self::current_rewards_epoch].
     pub fn voting_epoch(&self) -> Result<u32> {
         let voting_epoch = unwrap_int!(self.current_rewards_epoch.checked_add(1));
@@ -60,6 +65,11 @@ pub struct Gauge {
     pub is_disabled: bool,
 }
 
+impl Gauge {
+    /// Length of a [Gauge] in bytes.
+    pub const LEN: usize = PUBKEY_BYTES * 2 + 1;
+}
+
 /// A [GaugeVoter] represents an [locked_voter::Escrow] that can vote on gauges.
 #[account]
 #[derive(Copy, Debug, Default)]
@@ -83,6 +93,11 @@ pub struct GaugeVoter {
     pub weight_change_seqno: u64,
 }
 
+impl GaugeVoter {
+    /// Length of a [GaugeVoter] in bytes.
+    pub const LEN: usize = PUBKEY_BYTES * 3 + 4 + 8;
+}
+
 /// A [GaugeVote] is a user's vote for a given [Gauge].
 #[account]
 #[derive(Copy, Debug, Default)]
@@ -96,6 +111,11 @@ pub struct GaugeVote {
     pub weight: u32,
 }
 
+impl GaugeVote {
+    /// Length of a [GaugeVote] in bytes.
+    pub const LEN: usize = PUBKEY_BYTES * 2 + 4;
+}
+
 /// An [EpochGauge] is a [Gauge]'s total committed votes for a given epoch.
 ///
 /// Seeds:
@@ -118,6 +138,11 @@ pub struct EpochGauge {
     pub total_power: u64,
 }
 
+impl EpochGauge {
+    /// Length of an [EpochGauge] in bytes.
+    pub const LEN: usize = PUBKEY_BYTES + 4 + 8;
+}
+
 /// An [EpochGaugeVoter] is a [GaugeVoter]'s total committed votes for a
 /// given [Gauge] at a given epoch.
 #[account]
@@ -138,6 +163,11 @@ pub struct EpochGaugeVoter {
     pub allocated_power: u64,
 }
 
+impl EpochGaugeVoter {
+    /// Length of an [EpochGaugeVoter] in bytes.
+    pub const LEN: usize = PUBKEY_BYTES + 4 + 8 * 3;
+}
+
 /// An [EpochGaugeVote] is a user's committed votes for a given [Gauge] at a given epoch.
 ///
 /// Seeds:
@@ -159,6 +189,11 @@ pub struct EpochGaugeVote {
     pub allocated_power: u64,
 }
 
+impl EpochGaugeVote {
+    /// Length of an [EpochGaugeVote] in bytes.
+    pub const LEN: usize = 8;
+}
+
 impl EpochGaugeVote {
     /// Finds the address of an [EpochGaugeVote] for a given [GaugeVote] and voting epoch.
     pub fn find_program_address(gauge_vote: &Pubkey, voting_epoch: u32) -> (Pubkey, u8) {
@@ -169,3 +204,62 @@ impl EpochGaugeVote {
         )
     }
 }
+
+#[cfg(test)]
+#[allow(clippy::unwrap_used)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn test_gaugemeister_len() {
+        assert_eq!(
+            Gaugemeister::default().try_to_vec().unwrap().len(),
+            Gaugemeister::LEN
+        );
+    }
+
+    #[test]
+    fn test_gauge_voter_len() {
+        assert_eq!(
+            GaugeVoter::default().try_to_vec().unwrap().len(),
+            GaugeVoter::LEN
+        );
+    }
+
+    #[test]
+    fn test_gauge_len() {
+        assert_eq!(Gauge::default().try_to_vec().unwrap().len(), Gauge::LEN);
+    }
+
+    #[test]
+    fn test_gauge_vote_len() {
+        assert_eq!(
+            GaugeVote::default().try_to_vec().unwrap().len(),
+            GaugeVote::LEN
+        );
+    }
+
+    #[test]
+    fn test_epoch_gauge_voter_len() {
+        assert_eq!(
+            EpochGaugeVoter::default().try_to_vec().unwrap().len(),
+            EpochGaugeVoter::LEN
+        );
+    }
+
+    #[test]
+    fn test_epoch_gauge_len() {
+        assert_eq!(
+            EpochGauge::default().try_to_vec().unwrap().len(),
+            EpochGauge::LEN
+        );
+    }
+
+    #[test]
+    fn test_epoch_gauge_vote_len() {
+        assert_eq!(
+            EpochGaugeVote::default().try_to_vec().unwrap().len(),
+            EpochGaugeVote::LEN
+        );
+    }
+}
